@@ -5,7 +5,7 @@ use nu_protocol::{
         ImportPatternMember, Pipeline,
     },
     engine::StateWorkingSet,
-    span, Exportable, Overlay, PositionalArg, Span, SyntaxShape, Type, CONFIG_VARIABLE_ID,
+    span, Exportable, Overlay, PositionalArg, Span, SyntaxShape, Type,
 };
 use std::collections::HashSet;
 use std::path::{Path, PathBuf};
@@ -23,7 +23,7 @@ use crate::{
         parse_internal_call, parse_multispan_value, parse_signature, parse_string,
         parse_var_with_opt_type, trim_quotes,
     },
-    ParseError,
+    unescape_unquote_string, ParseError,
 };
 
 pub fn parse_def_predecl(
@@ -41,7 +41,7 @@ pub fn parse_def_predecl(
     };
 
     if (name == b"def" || name == b"def-env") && spans.len() >= 4 {
-        let (name_expr, ..) = parse_string(working_set, spans[1]);
+        let (name_expr, ..) = parse_string(working_set, spans[1], expand_aliases_denylist);
         let name = name_expr.as_string();
 
         working_set.enter_scope();
@@ -64,7 +64,7 @@ pub fn parse_def_predecl(
             }
         }
     } else if name == b"extern" && spans.len() == 3 {
-        let (name_expr, ..) = parse_string(working_set, spans[1]);
+        let (name_expr, ..) = parse_string(working_set, spans[1], expand_aliases_denylist);
         let name = name_expr.as_string();
 
         working_set.enter_scope();
@@ -529,6 +529,18 @@ pub fn parse_alias(
                 expand_aliases_denylist,
             );
 
+            if call.has_flag("help") {
+                return (
+                    Pipeline::from_vec(vec![Expression {
+                        expr: Expr::Call(call),
+                        span: span(spans),
+                        ty: Type::Any,
+                        custom_completion: None,
+                    }]),
+                    None,
+                );
+            }
+
             if spans.len() >= 4 {
                 let alias_name = working_set.get_span_contents(spans[1]);
 
@@ -892,7 +904,8 @@ pub fn parse_export(
                 call.head = span(&spans[0..=1]);
 
                 if let Some(name_span) = spans.get(2) {
-                    let (name_expr, err) = parse_string(working_set, *name_span);
+                    let (name_expr, err) =
+                        parse_string(working_set, *name_span, expand_aliases_denylist);
                     error = error.or(err);
                     call.add_positional(name_expr);
 
@@ -1132,7 +1145,7 @@ pub fn parse_module(
     let bytes = working_set.get_span_contents(spans[0]);
 
     if bytes == b"module" && spans.len() >= 3 {
-        let (module_name_expr, err) = parse_string(working_set, spans[1]);
+        let (module_name_expr, err) = parse_string(working_set, spans[1], expand_aliases_denylist);
         error = error.or(err);
 
         let module_name = module_name_expr
@@ -1299,9 +1312,10 @@ pub fn parse_use(
         } else {
             // TODO: Do not close over when loading module from file
             // It could be a file
-            if let Ok(module_filename) =
-                String::from_utf8(trim_quotes(&import_pattern.head.name).to_vec())
-            {
+
+            let (module_filename, err) =
+                unescape_unquote_string(&import_pattern.head.name, import_pattern.head.span);
+            if err.is_none() {
                 if let Some(module_path) =
                     find_in_dirs(&module_filename, working_set, &cwd, LIB_DIRS_ENV)
                 {
@@ -1359,7 +1373,11 @@ pub fn parse_use(
                     }
                 } else {
                     error = error.or(Some(ParseError::ModuleNotFound(import_pattern.head.span)));
-                    (ImportPattern::new(), Overlay::new())
+
+                    let mut import_pattern = ImportPattern::new();
+                    import_pattern.head.span = spans[1];
+
+                    (import_pattern, Overlay::new())
                 }
             } else {
                 return (garbage_pipeline(spans), Some(ParseError::NonUtf8(spans[1])));
@@ -1520,7 +1538,7 @@ pub fn parse_hide(
 
     if bytes == b"hide" && spans.len() >= 2 {
         for span in spans[1..].iter() {
-            let (_, err) = parse_string(working_set, *span);
+            let (_, err) = parse_string(working_set, *span, expand_aliases_denylist);
             error = error.or(err);
         }
 
@@ -1706,9 +1724,7 @@ pub fn parse_let(
                         let rhs_type = rvalue.ty.clone();
 
                         if let Some(var_id) = var_id {
-                            if var_id != CONFIG_VARIABLE_ID {
-                                working_set.set_variable_type(var_id, rhs_type);
-                            }
+                            working_set.set_variable_type(var_id, rhs_type);
                         }
 
                         let call = Box::new(Call {
@@ -1801,8 +1817,8 @@ pub fn parse_source(
             // Command and one file name
             if spans.len() >= 2 {
                 let name_expr = working_set.get_span_contents(spans[1]);
-                let name_expr = trim_quotes(name_expr);
-                if let Ok(filename) = String::from_utf8(name_expr.to_vec()) {
+                let (filename, err) = unescape_unquote_string(name_expr, spans[1]);
+                if err.is_none() {
                     if let Some(path) = find_in_dirs(&filename, working_set, &cwd, LIB_DIRS_ENV) {
                         if let Ok(contents) = std::fs::read(&path) {
                             // This will load the defs from the file into the
@@ -1952,26 +1968,27 @@ pub fn parse_register(
         .map(|expr| {
             let name_expr = working_set.get_span_contents(expr.span);
 
-            let name_expr = trim_quotes(name_expr);
-            String::from_utf8(name_expr.to_vec())
-                .map_err(|_| ParseError::NonUtf8(expr.span))
-                .and_then(|name| {
-                    if let Some(p) = find_in_dirs(&name, working_set, &cwd, PLUGIN_DIRS_ENV) {
-                        Ok(p)
-                    } else {
-                        Err(ParseError::RegisteredFileNotFound(name, expr.span))
-                    }
-                })
-                .and_then(|path| {
-                    if path.exists() & path.is_file() {
-                        Ok(path)
-                    } else {
-                        Err(ParseError::RegisteredFileNotFound(
-                            format!("{:?}", path),
-                            expr.span,
-                        ))
-                    }
-                })
+            let (name, err) = unescape_unquote_string(name_expr, expr.span);
+
+            if let Some(err) = err {
+                Err(err)
+            } else {
+                let path = if let Some(p) = find_in_dirs(&name, working_set, &cwd, PLUGIN_DIRS_ENV)
+                {
+                    p
+                } else {
+                    return Err(ParseError::RegisteredFileNotFound(name, expr.span));
+                };
+
+                if path.exists() & path.is_file() {
+                    Ok(path)
+                } else {
+                    Err(ParseError::RegisteredFileNotFound(
+                        format!("{:?}", path),
+                        expr.span,
+                    ))
+                }
+            }
         })
         .expect("required positional has being checked")
         .and_then(|path| {
